@@ -16,7 +16,6 @@
 # $Revision: 12021 $
 
 import datetime
-import logging
 
 from aldryn_newsblog.models import Article, ArticleTranslation
 from cms.models.pluginmodel import CMSPlugin
@@ -28,8 +27,9 @@ from django.db import transaction
 
 from Zephyrus.blog_extension.models import CallToActionModel
 from Zephyrus.blog_extension import settings as _settings 
+from Iuppiter.Logging import createLogger
 
-logger = logging.getLogger(__name__)
+logger = createLogger(__name__)
 
 class Command(BaseCommand):
 
@@ -124,7 +124,7 @@ class Command(BaseCommand):
                     formPlugin.save()
                     
                     logger.debug(
-                        f'Add plugin in article id: {article.id} title: articleTranslation: {articleTranslation.title}'
+                        f'Add plugin in article id: {article.id} title(articleTranslation): {articleTranslation.title}'
                     )
                     amount = amount + 1
                     
