@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: models.py 12169 2020-05-06 06:56:44Z Trista $
+# $Id: models.py 12242 2020-05-20 07:23:17Z Trista $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Trista $
-# $Date: 2020-05-06 14:56:44 +0800 (週三, 06 五月 2020) $
-# $Revision: 12169 $
+# $Date: 2020-05-20 15:23:17 +0800 (週三, 20 五月 2020) $
+# $Revision: 12242 $
 
 from functools import wraps
 from django import forms
@@ -222,5 +222,8 @@ class CallToActionStatistics(models.Model):
     token = models.CharField(max_length=80)
     email = models.CharField(max_length=500)
     count = models.IntegerField(default=0)
-    url = models.CharField(max_length=500)
+    url = models.CharField(max_length=500, blank=True, null=True)
+    article = models.ForeignKey(Article, related_name='callToActionStatistics', null=True)
+    
+   
 
