@@ -16,12 +16,14 @@
 # $Revision: 11069 $
 
 import datetime
-import logging
-import urllib
-import six
 import hashlib
-import pdfkit
+import logging
+import mimetypes
 import os
+import pdfkit
+import six
+import urllib
+
 
 from bs4 import BeautifulSoup
 from unidecode import unidecode
@@ -45,6 +47,7 @@ from django.urls import reverse
 from django.http import (
     HttpResponseRedirect,
     HttpResponsePermanentRedirect,
+    HttpResponse,
 )
 
 from djangocms_forms.models import FormDefinition
@@ -78,8 +81,8 @@ CALL_TO_ACTION_BASE_DIR = os.path.dirname(os.path.abspath(__file__))
 
 def renderArticle(request, articleId):
     article = get_object_or_404(Article, pk=hashid_to_int(articleId))
-    domain = Site.objects.get_current().domain
-    context = {'article': article, 'filename': f'{domain}-{article.slug}'}
+    websiteName = Site.objects.get_current().name
+    context = {'article': article, 'filename': f'[{websiteName}]-{article.slug}'}
     return render(request, _settings.CALL_TO_ACTION_PDF_BASE_TEMPLATE , context)
 
 class CallToActionEmailView(View):
@@ -139,7 +142,7 @@ def sendAndRedirect(request, email, fromUrl, redirectTo, actionId, formId=None,
     
     # determine whether this plugin belongs to a article detail page
     slug = fromUrl.split('/')[-2]
-    article = Article.objects.filter(translations__slug=slug)
+    article = Article.objects.filter(translations__slug=slug, translations__language_code=request.LANGUAGE_CODE)
     if article.exists():
         article = article[0]
         pluginUrl = None
@@ -331,14 +334,29 @@ def showTargetFile(request):
     
     def returnTargetFile(request, callToActionStatistics):
         if callToActionStatistics.action.targetFile:
+            targetFile = callToActionStatistics.action.targetFile
 
-            path = settings.BASE_DIR + \
-                settings.MEDIA_URL + \
-                str(callToActionStatistics.action.targetFile.file)
-
-            # response = serve(request, path, document_root=settings.BASE_DIR)
-            path = settings.MEDIA_URL + str(callToActionStatistics.action.targetFile.file)
-            return redirect(path)
+            path = settings.MEDIA_URL + str(targetFile.file)
+            with open(path[1:], 'rb') as f:
+                file = f.read()
+                
+            mimeType = mimetypes.guess_type(targetFile.original_filename)
+            if mimeType is not None:
+                contentType = mimeType[0]
+            else:
+                contentType = 'application/force-download'
+            if callToActionStatistics.action.fileName:
+                fileName = callToActionStatistics.action.fileName + '.' +targetFile.original_filename.split('.')[-1]
+            else:
+                fileName = targetFile.original_filename
+            response = HttpResponse(
+                file,
+                content_type=contentType
+            )
+            response['Content-Disposition'] = (
+                        "attachment; filename=%s" % (fileName, ))
+            response['Content-Transfer-Encoding'] = 'binary'
+            return response
 
         elif callToActionStatistics.action.linkUrl:
             return render(
@@ -348,8 +366,9 @@ def showTargetFile(request):
             )
 
         else:
-            domain = Site.objects.get_current().domain
-            websiteName = Site.objects.get_current().name
+            site = Site.objects.get_current()
+            domain = site.domain
+            websiteName = site.name
             
             if callToActionStatistics.article:
                 article = callToActionStatistics.article
@@ -382,7 +401,7 @@ def showTargetFile(request):
                 title = title.text.replace(' ', '')
                 title = title.replace('\n', '-')
 
-                fileName = f"{title}.pdf"
+                fileName = f"[{title}].pdf"
 
 
                 path = settings.MEDIA_URL + PDF_ROOT + fileName
@@ -393,9 +412,18 @@ def showTargetFile(request):
                     path[1:],
                     configuration=config,
                 )
-            # response = serve(request, path, document_root=settings.BASE_DIR)
+            with open(path[1:], 'rb') as f:
+                file = f.read()
+            response = HttpResponse(
+                file,
+                content_type='application/pdf'
+            )
+            response['Content-Disposition'] = (
+                        "attachment; filename=%s" % (fileName, ))
+            response['Content-Transfer-Encoding'] = 'binary'
+            # with chinese character in filename the file cannot dowload directly
 
-            return redirect(path)
+            return response
 
     key = request.GET.get('key')
     if request.POST.get('token'):
